pub struct ApplicationRecord {
pub id: String,
pub name: String,
pub description: Option<String>,
pub environments: BTreeMap<String, EnvironmentRecord>,
pub profiles: BTreeMap<String, ProfileRecord>,
pub experiments: BTreeMap<String, ExperimentRecord>,
}Expand description
An application with its nested environments, profiles and experiments.
Fields
id: Stringname: Stringdescription: Option<String>environments: BTreeMap<String, EnvironmentRecord>profiles: BTreeMap<String, ProfileRecord>experiments: BTreeMap<String, ExperimentRecord>Experiment definitions keyed by id, each storing its runs.